import dateFns from "date-fns";

let wx = require("weixin-js-sdk");

export class WXUtils {
  constructor() {
    // this._config();
  }

  config(appid, ticket) {
    this._config(appid, ticket);
  }

  //获取定位信息
  getLocation(type, success, fail, complete) {
    wx.ready(() => {
      wx.getLocation({
        type: type, // 默认为wgs84的gps坐标，如果要返回直接给openLocation用的火星坐标，可传入'gcj02'
        success: success,
        fail: fail,
        complete: complete
      });
    });
  }

  chooseImage(count, sizeType, sourceType, success, fail, complete) {
    wx.ready(() => {
      wx.chooseImage({
        count: count, // 默认9
        sizeType: sizeType, // 可以指定是原图还是压缩图，默认二者都有
        sourceType: sourceType, // 可以指定来源是相册还是相机，默认二者都有
        success: success,
        fail: fail,
        complete: complete
      });
    });
  }

  getLocalImgData(localId, success) {
    wx.ready(() => {
      wx.getLocalImgData({
        localId: localId, // 图片的localID
        success: success
      });
    });
  }

  uploadImage(localId, isShowProgressTips, success, fail) {
    wx.ready(() => {
      wx.uploadImage({
        localId: localId, // 图片的localID
        isShowProgressTips: isShowProgressTips,
        success: success,
        fail: fail
      });
    });
  }

  /**
   *
   * wx.onMenuShareAppMessage({
   * title: '', // 分享标题
   * desc: '', // 分享描述
   * link: '', // 分享链接，该链接域名必须与当前企业的可信域名一致
   * imgUrl: '', // 分享图标
   * type: '', // 分享类型,music、video或link，不填默认为link
   * dataUrl: '', // 如果type是music或video，则要提供数据链接，默认为空
   * success: function () {
   * // 用户确认分享后执行的回调函数
   * },
   * cancel: function () {
   * // 用户取消分享后执行的回调函数
   * }
   * });
   */
  shareToWX(title, desc, link, imgUrl, type, dataUrl, success, cancel) {
    wx.ready(() => {
      wx.onMenuShareAppMessage({
        title: title, // 分享标题
        desc: desc, // 分享描述
        link: link, // 分享链接，该链接域名必须与当前企业的可信域名一致
        imgUrl: imgUrl, // 分享图标
        type: type, // 分享类型,music、video或link，不填默认为link
        dataUrl: dataUrl, // 如果type是music或video，则要提供数据链接，默认为空
        success: success,
        cancel: cancel
      });
      wx.onMenuShareTimeline({
        title: title, // 分享标题
        desc: desc, // 分享描述
        link: link, // 分享链接，该链接域名必须与当前企业的可信域名一致
        imgUrl: imgUrl, // 分享图标
        type: type, // 分享类型,music、video或link，不填默认为link
        dataUrl: dataUrl, // 如果type是music或video，则要提供数据链接，默认为空
        success: success,
        cancel: cancel
      });
    });
  }

  async hideOptionMenu() {
    wx.ready(function() {
      wx.hideOptionMenu();
    });
  }

  async showOptionMenu() {
    wx.ready(function() {
      wx.showOptionMenu();
    });
  }

  async _config(appId, ticket) {
    const timestamp = dateFns.format(new Date(), "YYYYMMDDhhmmss");
    const locationUrl = window.location.href.split("#")[0];

    const sign =
      "jsapi_ticket=" +
      ticket +
      "&noncestr=HcGwOqUaLR2oCR6P&timestamp=" +
      timestamp +
      "&url=" +
      locationUrl;
    const signature = this.hex_sha1(sign);

    wx.config({
      beta: true, // 必须这么写，否则在微信插件有些jsapi问题
      debug: false,
      appId: appId,
      timestamp: timestamp,
      nonceStr: "HcGwOqUaLR2oCR6P",
      signature: signature,
      jsApiList: [
        "checkJsApi",
        "onMenuShareTimeline",
        "onMenuShareAppMessage",
        "onMenuShareQQ",
        "onMenuShareWeibo",
        "onMenuShareQZone",
        "hideMenuItems",
        "showMenuItems",
        "hideAllNonBaseMenuItem",
        "showAllNonBaseMenuItem",
        "translateVoice",
        "startRecord",
        "stopRecord",
        "onVoiceRecordEnd",
        "playVoice",
        "onVoicePlayEnd",
        "pauseVoice",
        "stopVoice",
        "uploadVoice",
        "downloadVoice",
        "chooseImage",
        "getLocalImgData",
        "previewImage",
        "uploadImage",
        "downloadImage",
        "getNetworkType",
        "openLocation",
        "getLocation",
        "hideOptionMenu",
        "showOptionMenu",
        "closeWindow",
        "scanQRCode",
        "chooseWXPay",
        "openProductSpecificView",
        "addCard",
        "chooseCard",
        "openCard"
      ],
      fail: function(errMsg) {
        alert(errMsg);
      }
    });
  }

  hexcase = 0;
  /* hex output format. 0 - lowercase; 1 - uppercase        */
  chrsz = 8;
  /* bits per input character. 8 - ASCII; 16 - Unicode      */

  hex_sha1(s) {
    return this.binb2hex(
      this.core_sha1(this.str2binb(s), s.length * this.chrsz)
    );
  }

  /*
    * Calculate the SHA-1 of an array of big-endian words, and a bit length
    */
  core_sha1(x, len) {
    /* append padding */
    x[len >> 5] |= 0x80 << (24 - (len % 32));
    x[(((len + 64) >> 9) << 4) + 15] = len;

    let w = new Array(80);
    let a = 1732584193;
    let b = -271733879;
    let c = -1732584194;
    let d = 271733878;
    let e = -1009589776;

    for (let i = 0; i < x.length; i += 16) {
      let olda = a;
      let oldb = b;
      let oldc = c;
      let oldd = d;
      let olde = e;

      for (let j = 0; j < 80; j++) {
        if (j < 16) w[j] = x[i + j];
        else w[j] = this.rol(w[j - 3] ^ w[j - 8] ^ w[j - 14] ^ w[j - 16], 1);
        let t = this.safe_add(
          this.safe_add(this.rol(a, 5), this.sha1_ft(j, b, c, d)),
          this.safe_add(this.safe_add(e, w[j]), this.sha1_kt(j))
        );
        e = d;
        d = c;
        c = this.rol(b, 30);
        b = a;
        a = t;
      }

      a = this.safe_add(a, olda);
      b = this.safe_add(b, oldb);
      c = this.safe_add(c, oldc);
      d = this.safe_add(d, oldd);
      e = this.safe_add(e, olde);
    }
    return [a, b, c, d, e];
  }

  /*
    * Perform the appropriate triplet combination function for the current
    * iteration
    */
  sha1_ft(t, b, c, d) {
    if (t < 20) return (b & c) | (~b & d);
    if (t < 40) return b ^ c ^ d;
    if (t < 60) return (b & c) | (b & d) | (c & d);
    return b ^ c ^ d;
  }

  /*
    * Determine the appropriate additive constant for the current iteration
    */
  sha1_kt(t) {
    return t < 20
      ? 1518500249
      : t < 40
        ? 1859775393
        : t < 60
          ? -1894007588
          : -899497514;
  }

  /*
    * Add integers, wrapping at 2^32. This uses 16-bit operations internally
    * to work around bugs in some JS interpreters.
    */
  safe_add(x, y) {
    let lsw = (x & 0xffff) + (y & 0xffff);
    let msw = (x >> 16) + (y >> 16) + (lsw >> 16);
    return (msw << 16) | (lsw & 0xffff);
  }

  /*
    * Bitwise rotate a 32-bit number to the left.
    */
  rol(num, cnt) {
    return (num << cnt) | (num >>> (32 - cnt));
  }

  /*
    * Convert an 8-bit or 16-bit string to an array of big-endian words
    * In 8-bit function, characters >255 have their hi-byte silently ignored.
    */
  str2binb(str) {
    let bin = [];
    let mask = (1 << this.chrsz) - 1;
    for (let i = 0; i < str.length * this.chrsz; i += this.chrsz)
      bin[i >> 5] |=
        (str.charCodeAt(i / this.chrsz) & mask) << (32 - this.chrsz - (i % 32));
    return bin;
  }

  /*
    * Convert an array of big-endian words to a hex string.
    */
  binb2hex(binarray) {
    let hex_tab = this.hexcase ? "0123456789ABCDEF" : "0123456789abcdef";
    let str = "";
    for (let i = 0; i < binarray.length * 4; i++) {
      str +=
        hex_tab.charAt((binarray[i >> 2] >> ((3 - (i % 4)) * 8 + 4)) & 0xf) +
        hex_tab.charAt((binarray[i >> 2] >> ((3 - (i % 4)) * 8)) & 0xf);
    }
    return str;
  }
}

const wxUtils = new WXUtils();
export default wxUtils;
