import wxUtils from './weixin';

let wx = require('weixin-js-sdk');

//解决ios  uiwebview下面img通过src属性无法展示的问题
window.wx = wx;

console.log('正在使用weixinsdk...');

function configWX(appid, ticket) {
  wxUtils.config(appid, ticket);
}

function previewImage(params = {}) {
  wx.previewImage(params);
}

function chooseImage(params = {}) {
  if (!params.sourceType || params.sourceType.length == 0) {
    params.sourceType = ['album', 'camera'];
  }

  return new Promise((resolve, reject) => {
    wx.chooseImage({
      count: params.count || 9, // 默认9
      sizeType: ['compressed'], // 可以指定是原图还是压缩图，默认二者都有
      sourceType: params.sourceType, // 可以指定来源是相册还是相机，默认二者都有
      success: function(res) {
        resolve(res); // 返回选定照片的本地ID列表，localId可以作为img标签的src属性显示图片
      },
      fail: function(res) {
        reject(new Error(res.errMsg));
      }
    });
  });
}

function getLocalImgData(params = {}) {
  return new Promise((resolve, reject) => {
    params.success = resolve;
    params.fail = reject;

    wx.getLocalImgData(params);
  });
}

function uploadImage(params = {}) {
  return new Promise((resolve, reject) => {
    wx.uploadImage({
      localId: params.localId, // 需要上传的图片的本地ID，由chooseImage接口获得
      isShowProgressTips: params.isShowProgressTips, // 默认为1，显示进度提示
      success: function(res) {
        resolve(res); // 返回图片的服务器端ID
      },
      error: function(error) {
        reject(error.errMsg);
      }
    });
  });
}

function getLocation(params = {}) {
  // 默认为wgs84的gps坐标，如果要返回直接给openLocation用的火星坐标，可传入'gcj02'
  if (!params.type) params.type = 'wgs84';

  return new Promise(function(resolve, reject) {
    wx.getLocation({
      type: params.type,
      success: function(res) {
        var latitude = res.latitude; // 纬度，浮点数，范围为90 ~ -90
        var longitude = res.longitude; // 经度，浮点数，范围为180 ~ -180。

        rt
          .getWXLocation(longitude, latitude)
          .then(function(res) {
            return resolve(res);
          })
          .catch(function(errorMessage) {
            reject(new Error(errorMessage));
          });
      },
      fail: function(res) {
        reject(new Error(res.errMsg));
      }
    });
  });
}

function scanQRCode() {
  return new Promise((resolve, reject) => {
    wx.scanQRCode({
      needResult: 1, // 默认为0，扫描结果由微信处理，1则直接返回扫描结果，
      scanType: ['qrCode', 'barCode'], // 可以指定扫二维码还是一维码，默认二者都有
      success: function(res) {
        var result = res.resultStr; // 当needResult 为 1 时，扫码返回的结果
        if (result.includes(',')) {
          result = result.split(',')[1];
        }
        return resolve(result);
      },
      error: function(error) {
        reject(error.errMsg);
      }
    });
  });
}

function closeWindow() {
  wx.closeWindow();
}

export { configWX, chooseImage, getLocalImgData, getLocation, scanQRCode, closeWindow, uploadImage, previewImage };
